@@ -279,7 +279,7 @@ Many commands that accept URLs also accept location aliases too.  See
 
 _basic_help = \
 """Bazaar %s -- a free distributed version-control tool
-http://www.bazaar.canonical.com/
+http://bazaar.canonical.com/
 
 Basic commands:
   bzr init           makes this directory a versioned branch
@@ -512,7 +512,7 @@ Useful commands::
 
   checkout     Create a working tree when a branch does not have one.
   remove-tree  Removes the working tree from a branch when it is safe to do so.
-  update       When a working tree is out of sync with it's associated branch
+  update       When a working tree is out of sync with its associated branch
                this will update the tree to match the branch.
 """
 
@@ -591,8 +591,9 @@ Column 3 - execute::
 _env_variables = \
 """Environment Variables
 
-=================== =======================================================================
-BZRPATH             Path where bzr is to look for shell plugin external commands.
+=================== ===========================================================
+BZRPATH             Path where bzr is to look for shell plugin external
+                    commands.
 BZR_EMAIL           E-Mail address of the user. Overrides EMAIL.
 EMAIL               E-Mail address of the user.
 BZR_EDITOR          Editor for editing commit messages. Overrides EDITOR.
@@ -601,17 +602,21 @@ BZR_PLUGIN_PATH     Paths where bzr should look for plugins.
 BZR_DISABLE_PLUGINS Plugins that bzr should not load.
 BZR_PLUGINS_AT      Plugins to load from a directory not in BZR_PLUGIN_PATH.
 BZR_HOME            Directory holding .bazaar config dir. Overrides HOME.
-BZR_HOME (Win32)    Directory holding bazaar config dir. Overrides APPDATA and HOME.
+BZR_HOME (Win32)    Directory holding bazaar config dir. Overrides APPDATA and
+                    HOME.
 BZR_REMOTE_PATH     Full name of remote 'bzr' command (for bzr+ssh:// URLs).
-BZR_SSH             Path to SSH client, or one of paramiko, openssh, sshcorp, plink.
+BZR_SSH             Path to SSH client, or one of paramiko, openssh, sshcorp,
+                    plink or lsh.
 BZR_LOG             Location of .bzr.log (use '/dev/null' to suppress log).
 BZR_LOG (Win32)     Location of .bzr.log (use 'NUL' to suppress log).
 BZR_COLUMNS         Override implicit terminal width.
-BZR_CONCURRENCY     Number of processes that can be run concurrently (selftest).
-BZR_PROGRESS_BAR    Override the progress display. Values are 'none', 'dots', or 'tty'.
+BZR_CONCURRENCY     Number of processes that can be run concurrently (selftest)
+BZR_PROGRESS_BAR    Override the progress display. Values are 'none', 'dots',
+                    or 'tty'.
 BZR_PDB             Control whether to launch a debugger on error.
-BZR_SIGQUIT_PDB     Control whether SIGQUIT behaves normally or invokes a breakin debugger.
-=================== =======================================================================
+BZR_SIGQUIT_PDB     Control whether SIGQUIT behaves normally or invokes a
+                    breakin debugger.
+=================== ===========================================================
 """
 
 
