@@ -121,12 +121,12 @@ class TestControlDir(TestCaseWithControlDir):
             bzrdir.destroy_workingtree()
         except errors.UnsupportedOperation:
             raise TestSkipped('Format does not support destroying tree')
-        self.failIfExists('tree/file')
+        self.assertPathDoesNotExist('tree/file')
         self.assertRaises(errors.NoWorkingTree, bzrdir.open_workingtree)
         bzrdir.create_workingtree()
-        self.failUnlessExists('tree/file')
+        self.assertPathExists('tree/file')
         bzrdir.destroy_workingtree_metadata()
-        self.failUnlessExists('tree/file')
+        self.assertPathExists('tree/file')
         self.assertRaises(errors.NoWorkingTree, bzrdir.open_workingtree)
 
     def test_destroy_branch(self):
@@ -762,7 +762,7 @@ class TestControlDir(TestCaseWithControlDir):
                 create_tree_if_local=False)
         except errors.MustHaveWorkingTree:
             raise TestNotApplicable("control dir format requires working tree")
-        self.failIfExists('target/foo')
+        self.assertPathDoesNotExist('target/foo')
         self.assertEqual(tree.branch.last_revision(),
                          target.open_branch().last_revision())
 
@@ -807,7 +807,7 @@ class TestControlDir(TestCaseWithControlDir):
         t = self.get_transport()
         readonly_t = self.get_readonly_transport()
         made_control = self.bzrdir_format.initialize(t.base)
-        self.failUnless(isinstance(made_control, controldir.ControlDir))
+        self.assertIsInstance(made_control, controldir.ControlDir)
         self.assertEqual(self.bzrdir_format,
                          controldir.ControlDirFormat.find_format(readonly_t))
         direct_opened_dir = self.bzrdir_format.open(readonly_t)
@@ -816,7 +816,7 @@ class TestControlDir(TestCaseWithControlDir):
                          opened_dir._format)
         self.assertEqual(direct_opened_dir._format,
                          opened_dir._format)
-        self.failUnless(isinstance(opened_dir, controldir.ControlDir))
+        self.assertIsInstance(opened_dir, controldir.ControlDir)
 
     def test_format_initialize_on_transport_ex(self):
         t = self.get_transport('dir')
@@ -1029,7 +1029,7 @@ class TestControlDir(TestCaseWithControlDir):
         made_control = self.bzrdir_format.initialize(t.base)
         made_repo = made_control.create_repository()
         made_branch = made_control.create_branch()
-        self.failUnless(isinstance(made_branch, bzrlib.branch.Branch))
+        self.assertIsInstance(made_branch, bzrlib.branch.Branch)
         self.assertEqual(made_control, made_branch.bzrdir)
 
     def test_open_branch(self):
@@ -1044,8 +1044,8 @@ class TestControlDir(TestCaseWithControlDir):
         made_branch = made_control.create_branch()
         opened_branch = made_control.open_branch()
         self.assertEqual(made_control, opened_branch.bzrdir)
-        self.failUnless(isinstance(opened_branch, made_branch.__class__))
-        self.failUnless(isinstance(opened_branch._format, made_branch._format.__class__))
+        self.assertIsInstance(opened_branch, made_branch.__class__)
+        self.assertIsInstance(opened_branch._format, made_branch._format.__class__)
 
     def test_list_branches(self):
         if not self.bzrdir_format.is_supported():
@@ -1122,8 +1122,8 @@ class TestControlDir(TestCaseWithControlDir):
         made_repo = made_control.create_repository()
         opened_repo = made_control.open_repository()
         self.assertEqual(made_control, opened_repo.bzrdir)
-        self.failUnless(isinstance(opened_repo, made_repo.__class__))
-        self.failUnless(isinstance(opened_repo._format, made_repo._format.__class__))
+        self.assertIsInstance(opened_repo, made_repo.__class__)
+        self.assertIsInstance(opened_repo._format, made_repo._format.__class__)
 
     def test_create_workingtree(self):
         # a bzrdir can construct a working tree for itself.
@@ -1137,7 +1137,7 @@ class TestControlDir(TestCaseWithControlDir):
         made_repo = made_control.create_repository()
         made_branch = made_control.create_branch()
         made_tree = self.createWorkingTreeOrSkip(made_control)
-        self.failUnless(isinstance(made_tree, workingtree.WorkingTree))
+        self.assertIsInstance(made_tree, workingtree.WorkingTree)
         self.assertEqual(made_control, made_tree.bzrdir)
 
     def test_create_workingtree_revision(self):
@@ -1176,8 +1176,8 @@ class TestControlDir(TestCaseWithControlDir):
                               % (self.bzrdir_format, t))
         opened_tree = made_control.open_workingtree()
         self.assertEqual(made_control, opened_tree.bzrdir)
-        self.failUnless(isinstance(opened_tree, made_tree.__class__))
-        self.failUnless(isinstance(opened_tree._format, made_tree._format.__class__))
+        self.assertIsInstance(opened_tree, made_tree.__class__)
+        self.assertIsInstance(opened_tree._format, made_tree._format.__class__)
 
     def test_get_branch_transport(self):
         dir = self.make_bzrdir('.')
@@ -1379,8 +1379,8 @@ class TestControlDir(TestCaseWithControlDir):
         old_url, new_url = tree.bzrdir.backup_bzrdir()
         old_path = urlutils.local_path_from_url(old_url)
         new_path = urlutils.local_path_from_url(new_url)
-        self.failUnlessExists(old_path)
-        self.failUnlessExists(new_path)
+        self.assertPathExists(old_path)
+        self.assertPathExists(new_path)
         for (((dir_relpath1, _), entries1),
              ((dir_relpath2, _), entries2)) in izip(
                 osutils.walkdirs(old_path),
@@ -1414,7 +1414,7 @@ class TestControlDir(TestCaseWithControlDir):
     def test_format_description(self):
         dir = self.make_bzrdir('.')
         text = dir._format.get_format_description()
-        self.failUnless(len(text))
+        self.assertTrue(len(text))
 
 
 class TestBreakLock(TestCaseWithControlDir):
