@@ -19,6 +19,7 @@
 import os
 
 from bzrlib import (
+    config,
     errors,
     graph,
     inventory,
@@ -1322,6 +1323,10 @@ class TestCommitBuilder(per_repository.TestCaseWithRepository):
         # Ensure that when no username is available but a committer is
         # supplied, commit works.
         self.overrideEnv('EMAIL', None)
+        self.overrideEnv('BZR_EMAIL', None)
+        # Also, make sure that it's not inferred from mailname.
+        self.overrideAttr(config, '_auto_user_id',
+            lambda: (None, None))
         tree = self.make_branch_and_tree(".")
         tree.lock_write()
         try:
