@@ -41,6 +41,7 @@ from bzrlib import (
     )
 from bzrlib.tests import (
     features,
+    TestSkipped,
     scenarios,
     )
 from bzrlib.util.configobj import configobj
@@ -505,7 +506,7 @@ class TestIniConfigBuilding(TestIniConfig):
     def test_cached(self):
         my_config = config.IniBasedConfig.from_string(sample_config_text)
         parser = my_config._get_parser()
-        self.failUnless(my_config._get_parser() is parser)
+        self.assertTrue(my_config._get_parser() is parser)
 
     def _dummy_chown(self, path, uid, gid):
         self.path, self.uid, self.gid = path, uid, gid
@@ -764,7 +765,7 @@ class TestGetConfig(tests.TestCase):
             parser = my_config._get_parser()
         finally:
             config.ConfigObj = oldparserclass
-        self.failUnless(isinstance(parser, InstrumentedConfigObj))
+        self.assertIsInstance(parser, InstrumentedConfigObj)
         self.assertEqual(parser._calls, [('__init__', config.config_filename(),
                                           'utf-8')])
 
@@ -781,7 +782,7 @@ class TestBranchConfig(tests.TestCaseWithTransport):
         my_config = config.BranchConfig(branch)
         location_config = my_config._get_location_config()
         self.assertEqual(branch.base, location_config.location)
-        self.failUnless(location_config is my_config._get_location_config())
+        self.assertIs(location_config, my_config._get_location_config())
 
     def test_get_config(self):
         """The Branch.get_config method works properly"""
@@ -1020,7 +1021,7 @@ class TestLocationConfig(tests.TestCaseInTempDir, TestOptionsMixin):
             parser = my_config._get_parser()
         finally:
             config.ConfigObj = oldparserclass
-        self.failUnless(isinstance(parser, InstrumentedConfigObj))
+        self.assertIsInstance(parser, InstrumentedConfigObj)
         self.assertEqual(parser._calls,
                          [('__init__', config.locations_config_filename(),
                            'utf-8')])
@@ -1028,8 +1029,8 @@ class TestLocationConfig(tests.TestCaseInTempDir, TestOptionsMixin):
     def test_get_global_config(self):
         my_config = config.BranchConfig(FakeBranch('http://example.com'))
         global_config = my_config._get_global_config()
-        self.failUnless(isinstance(global_config, config.GlobalConfig))
-        self.failUnless(global_config is my_config._get_global_config())
+        self.assertIsInstance(global_config, config.GlobalConfig)
+        self.assertIs(global_config, my_config._get_global_config())
 
     def test__get_matching_sections_no_match(self):
         self.get_branch_config('/')
@@ -2237,3 +2238,25 @@ class TestPlainTextCredentialStore(tests.TestCase):
 # test_user_prompted ?
 class TestAuthenticationRing(tests.TestCaseWithTransport):
     pass
+
+
+class TestAutoUserId(tests.TestCase):
+    """Test inferring an automatic user name."""
+
+    def test_auto_user_id(self):
+        """Automatic inference of user name.
+        
+        This is a bit hard to test in an isolated way, because it depends on
+        system functions that go direct to /etc or perhaps somewhere else.
+        But it's reasonable to say that on Unix, with an /etc/mailname, we ought
+        to be able to choose a user name with no configuration.
+        """
+        if sys.platform == 'win32':
+            raise TestSkipped("User name inference not implemented on win32")
+        realname, address = config._auto_user_id()
+        if os.path.exists('/etc/mailname'):
+            self.assertTrue(realname)
+            self.assertTrue(address)
+        else:
+            self.assertEquals((None, None), (realname, address))
+
