@@ -628,18 +628,18 @@ class TestLockDir(TestCaseWithTransport):
         lf1 = LockDir(t, 'test_lock')
 
         lf1.create()
-        self.failUnless(t.has('test_lock'))
+        self.assertTrue(t.has('test_lock'))
 
         t.rmdir('test_lock')
-        self.failIf(t.has('test_lock'))
+        self.assertFalse(t.has('test_lock'))
 
         # This will create 'test_lock' if it needs to
         lf1.lock_write()
-        self.failUnless(t.has('test_lock'))
-        self.failUnless(t.has('test_lock/held/info'))
+        self.assertTrue(t.has('test_lock'))
+        self.assertTrue(t.has('test_lock/held/info'))
 
         lf1.unlock()
-        self.failIf(t.has('test_lock/held/info'))
+        self.assertFalse(t.has('test_lock/held/info'))
 
     def test__format_lock_info(self):
         ld1 = self.get_lock()
