@@ -39,7 +39,7 @@ class TestRegistry(tests.TestCase):
         a_registry = registry.Registry()
         self.register_stuff(a_registry)
 
-        self.failUnless(a_registry.default_key is None)
+        self.assertTrue(a_registry.default_key is None)
 
         # test get() (self.default_key is None)
         self.assertRaises(KeyError, a_registry.get)
@@ -49,7 +49,7 @@ class TestRegistry(tests.TestCase):
 
         # test _set_default_key
         a_registry.default_key = 'five'
-        self.failUnless(a_registry.default_key == 'five')
+        self.assertTrue(a_registry.default_key == 'five')
         self.assertEqual(5, a_registry.get())
         self.assertEqual(5, a_registry.get(None))
         # If they ask for a specific entry, they should get KeyError
@@ -64,9 +64,9 @@ class TestRegistry(tests.TestCase):
         a_registry = registry.Registry()
         self.register_stuff(a_registry)
 
-        self.failUnless('one' in a_registry)
+        self.assertTrue('one' in a_registry)
         a_registry.remove('one')
-        self.failIf('one' in a_registry)
+        self.assertFalse('one' in a_registry)
         self.assertRaises(KeyError, a_registry.get, 'one')
 
         a_registry.register('one', 'one')
@@ -304,7 +304,7 @@ class TestRegistryWithDirs(tests.TestCaseInTempDir):
         self.assertEqual(['function', 'klass', 'module', 'obj'],
                          sorted(a_registry.keys()))
         # The plugin should not be loaded until we grab the first object
-        self.failIf(plugin_name in sys.modules)
+        self.assertFalse(plugin_name in sys.modules)
 
         # By default the plugin won't be in the search path
         self.assertRaises(ImportError, a_registry.get, 'obj')
@@ -314,7 +314,7 @@ class TestRegistryWithDirs(tests.TestCaseInTempDir):
         try:
             obj = a_registry.get('obj')
             self.assertEqual('foo', obj)
-            self.failUnless(plugin_name in sys.modules)
+            self.assertTrue(plugin_name in sys.modules)
 
             # Now grab another object
             func = a_registry.get('function')
