@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2010 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,11 +34,11 @@ class TestRevert(tests.TestCaseWithTransport):
         self.addCleanup(target_tree.unlock)
         merge.merge_inner(target_tree.branch, source_tree.basis_tree(),
                           target_tree.basis_tree(), this_tree=target_tree)
-        self.failUnlessExists('target/dir')
-        self.failUnlessExists('target/dir/contents')
+        self.assertPathExists('target/dir')
+        self.assertPathExists('target/dir/contents')
         target_tree.revert()
-        self.failIfExists('target/dir/contents')
-        self.failIfExists('target/dir')
+        self.assertPathDoesNotExist('target/dir/contents')
+        self.assertPathDoesNotExist('target/dir')
 
     def test_revert_new(self):
         """Only locally-changed new files should be preserved when reverting
@@ -60,26 +60,26 @@ class TestRevert(tests.TestCaseWithTransport):
         tree.add('new_file')
         basis_tree = tree.branch.repository.revision_tree(tree.last_revision())
         tree.revert()
-        self.failUnlessExists('tree/new_file')
+        self.assertPathExists('tree/new_file')
 
         # unchanged files should be deleted
         tree.add('new_file')
         tree.commit('add new_file')
         tree.revert(old_tree=basis_tree)
-        self.failIfExists('tree/new_file')
+        self.assertPathDoesNotExist('tree/new_file')
 
         # files should be deleted if their changes came from merges
         merge_target.merge_from_branch(tree.branch)
-        self.failUnlessExists('merge_target/new_file')
+        self.assertPathExists('merge_target/new_file')
         merge_target.revert()
-        self.failIfExists('merge_target/new_file')
+        self.assertPathDoesNotExist('merge_target/new_file')
 
         # files should not be deleted if changed after a merge
         merge_target.merge_from_branch(tree.branch)
-        self.failUnlessExists('merge_target/new_file')
+        self.assertPathExists('merge_target/new_file')
         self.build_tree_contents([('merge_target/new_file', 'new_contents')])
         merge_target.revert()
-        self.failUnlessExists('merge_target/new_file')
+        self.assertPathExists('merge_target/new_file')
 
     def tree_with_executable(self):
         tree = self.make_branch_and_tree('tree')
@@ -127,11 +127,11 @@ class TestRevert(tests.TestCaseWithTransport):
         tree.commit('added file', rev_id='rev1')
         os.unlink('file')
         tree.commit('removed file')
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
         tree.revert(old_tree=tree.branch.repository.revision_tree('rev1'))
-        self.failUnlessExists('file')
+        self.assertPathExists('file')
         tree.revert()
-        self.failIfExists('file')
+        self.assertPathDoesNotExist('file')
         self.assertEqual({}, tree.merge_modified())
 
     def test_empty_deprecated(self):
@@ -154,6 +154,17 @@ class TestRevert(tests.TestCaseWithTransport):
         os.rmdir('dir')
         tree.remove(['dir/', 'dir/file1', 'dir/file2'])
         tree.revert(['dir/file1'])
-        self.failUnlessExists('dir/file1')
-        self.failIfExists('dir/file2')
+        self.assertPathExists('dir/file1')
+        self.assertPathDoesNotExist('dir/file2')
         self.assertEqual('dir-id', tree.path2id('dir'))
+
+    def test_revert_root_id_change(self):
+        tree = self.make_branch_and_tree('.')
+        tree.set_root_id('initial-root-id')
+        self.build_tree(['file1'])
+        tree.add(['file1'])
+        tree.commit('first')
+        tree.set_root_id('temp-root-id')
+        self.assertEqual('temp-root-id', tree.get_root_id())
+        tree.revert()
+        self.assertEqual('initial-root-id', tree.get_root_id())
