@@ -43,10 +43,9 @@ class TestUpgrade(tests.TestCaseWithTransport):
         control = bzrdir.BzrDir.open('.')
         b = control.open_branch()
         # tsk, peeking under the covers.
-        self.failUnless(
-            isinstance(
+        self.assertIsInstance(
                 control._format,
-                bzrdir.BzrDirFormat.get_default_format().__class__))
+                bzrdir.BzrDirFormat.get_default_format().__class__)
         rh = b.revision_history()
         eq(rh,
            ['mbp@sourcefrog.net-20051004035611-176b16534b086b3c',
@@ -153,7 +152,7 @@ class TestUpgrade(tests.TestCaseWithTransport):
         # We have covered the scope of this test, we may as well check that
         # upgrade has not eaten our data, even if it's a bit redundant with
         # other tests.
-        self.failUnless(isinstance(control._format, bzrdir.BzrDirMetaFormat1))
+        self.assertIsInstance(control._format, bzrdir.BzrDirMetaFormat1)
         b = control.open_branch()
         self.assertEquals(b.revision_history(),
            ['mbp@sourcefrog.net-20051004035611-176b16534b086b3c',
@@ -233,7 +232,7 @@ class TestUpgrade(tests.TestCaseWithTransport):
         self.assertEqual(rev_id, new_tree.last_revision())
         for path in ['basis-inventory-cache', 'inventory', 'last-revision',
             'pending-merges', 'stat-cache']:
-            self.failIfExists('tree/.bzr/checkout/' + path)
+            self.assertPathDoesNotExist('tree/.bzr/checkout/' + path)
 
     def test_convert_knit_merges_dirstate(self):
         tree = self.make_branch_and_tree('tree', format='knit')
@@ -251,7 +250,7 @@ class TestUpgrade(tests.TestCaseWithTransport):
         self.assertEqual([rev_id2, rev_id3], new_tree.get_parent_ids())
         for path in ['basis-inventory-cache', 'inventory', 'last-revision',
             'pending-merges', 'stat-cache']:
-            self.failIfExists('tree/.bzr/checkout/' + path)
+            self.assertPathDoesNotExist('tree/.bzr/checkout/' + path)
 
 
 _upgrade1_template = \
@@ -435,7 +434,7 @@ class TestSmartUpgrade(tests.TestCaseWithTransport):
         self.assertLength(1, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('branch1/backup.bzr.~1~')
+        self.assertPathExists('branch1/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
 
@@ -448,9 +447,9 @@ class TestSmartUpgrade(tests.TestCaseWithTransport):
         self.assertLength(1, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('branch1')
-        self.failUnlessExists('branch1/.bzr')
-        self.failIfExists('branch1/backup.bzr.~1~')
+        self.assertPathExists('branch1')
+        self.assertPathExists('branch1/.bzr')
+        self.assertPathDoesNotExist('branch1/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
 
@@ -474,9 +473,9 @@ class TestSmartUpgrade(tests.TestCaseWithTransport):
         self.assertLength(3, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('repo/backup.bzr.~1~')
-        self.failUnlessExists('repo/branch1/backup.bzr.~1~')
-        self.failUnlessExists('repo/branch2/backup.bzr.~1~')
+        self.assertPathExists('repo/backup.bzr.~1~')
+        self.assertPathExists('repo/branch1/backup.bzr.~1~')
+        self.assertPathExists('repo/branch2/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
         b1 = branch.Branch.open('repo/branch1')
@@ -491,11 +490,11 @@ class TestSmartUpgrade(tests.TestCaseWithTransport):
         self.assertLength(3, worked)
         self.assertEqual(worked[0], control)
         self.assertLength(0, issues)
-        self.failUnlessExists('repo')
-        self.failUnlessExists('repo/.bzr')
-        self.failIfExists('repo/backup.bzr.~1~')
-        self.failIfExists('repo/branch1/backup.bzr.~1~')
-        self.failIfExists('repo/branch2/backup.bzr.~1~')
+        self.assertPathExists('repo')
+        self.assertPathExists('repo/.bzr')
+        self.assertPathDoesNotExist('repo/backup.bzr.~1~')
+        self.assertPathDoesNotExist('repo/branch1/backup.bzr.~1~')
+        self.assertPathDoesNotExist('repo/branch2/backup.bzr.~1~')
         self.assertEqual(control.open_repository()._format,
                          self.to_format._repository_format)
         b1 = branch.Branch.open('repo/branch1')
